@@ -1,8 +1,8 @@
-from stringcompare.functions import hashing_search
-from stringcompare.functions import linear_search
-from stringcompare.functions import create_chart
-from stringcompare.functions import generate_data
-from stringcompare.functions import measure_time
+from stringcompare.functions.hashing_search import hashing_search
+from stringcompare.functions.linear_search import linear_search
+from stringcompare.functions.create_chart import create_chart
+from stringcompare.functions.generate_data import generate_data
+from stringcompare.functions.measure_time import measure_time
 
 import click
 
